@@ -1,10 +1,11 @@
 print.semtreeControl <- function(x, ...)
 {
-	stopifnot(class(x)=="semtree.control")
+	stopifnot(is(x, "semtree.control"))
 
 	cat("SEM-Tree control\n----------------\n")
 
 	cat("Splitting Method: ", x$method,"\n")
+	cat("Test Type: ",x$test.type,"\n")
 	cat("Alpha Level: ", x$alpha,"\n");
 	cat("Bonferroni Correction:", x$bonferroni,"\n")
 	cat("Minimum Number of Cases: ", x$min.N,"\n")
